<!--
SPDX-FileCopyrightText: 2023 The eminus developers
SPDX-License-Identifier: Apache-2.0
-->
# io

File input and output functionalities.

| File      | Description |
| :-------: | :---------: |
| cube.py   | CUBE file handling |
| gth.py    | GTH file handling |
| json.py   | JSON file handling |
| pdb.py    | PDB file handling |
| poscar.py | POSCAR file handling |
| traj.py   | TRAJ file handling |
| xyz.py    | XYZ file handling |
